@@ -21,7 +21,7 @@ Readonly::Hash our %PRESETS => (
 	],
 );
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -69,7 +69,7 @@ sub run {
 	}
 
 	if ($PRESETS{$self->{'_opts'}->{'p'}}[0] > @ARGV) {
-		print 'Wrong number of arguments (need '.$PRESETS{$self->{'_opts'}->{'p'}}[0].
+		print STDERR 'Wrong number of arguments (need '.$PRESETS{$self->{'_opts'}->{'p'}}[0].
 			" for command '".$PRESETS{$self->{'_opts'}->{'p'}}[1]."').\n";
 		return 1;
 	}
@@ -182,12 +182,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2023 Michal Josef Špaček
+© 2023-2024 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
